import { CloseOutlined, ColumnWidthOutlined, SearchOutlined } from "@ant-design/icons"
import { Button, Checkbox, Input, InputNumber, message, Modal, Popover, Space, Spin, Tooltip } from "antd"
import React, { useCallback, useEffect, useState } from "react"
import './index.less'
import { ReactComponent as DrawStem } from '@/assets/drawStem.svg'
import { SortableContainer, SortableElement, SortableHandle } from "react-sortable-hoc";
import arrayMove from "array-move";

const DragHandle = SortableHandle(() => <DrawStem className='draw' />);
const SortableItem = SortableElement(({ item, del, setConfig }: any) => {
    const [visible, setVisible] = useState<boolean>(false)
    const [width, setWidth] = useState<number>(item?.width || 0)
    return <li className='liDraw'>
        <div className='lileft'>
            <DragHandle />
            <div>{item.title}</div>
        </div>
        <Space style={{ float: 'right', marginRight: 10 }}>
            <Popover
                content={
                    <div>
                        <InputNumber min={0} max={500} onChange={(value: number) => {
                            if (value) {
                                setWidth(value)
                            }
                        }} value={width} size='small' />
                        <Button type='primary' size='small' onClick={() => {
                            setConfig({ ...item, width })
                            setVisible(false)
                        }}>OK</Button>
                    </div>
                }
                trigger="click"
                visible={visible}
                placement='left'

                onVisibleChange={(visible) => { setVisible(visible) }}
            >
                <Tooltip title='宽度设置'><a><ColumnWidthOutlined /></a></Tooltip>
            </Popover>
        </Space>
        {item.label !== 'pos_type' && <Tooltip title='删除'><div className="clear" onClick={() => { del() }}><a><CloseOutlined /></a></div></Tooltip>}
    </li>
});
/** 外层 */
const SortableList = SortableContainer(({ children }: { children: any }) => (<ul className='selectedList'>{children}</ul>));

interface dataProps {
    title: string,
    label: string,
    dataIndex: string,
    disabled: boolean
}

interface DataProps {
    label: string,
    data: dataProps[]
}

/**
 * 自定义列
 */
type customProps = {
    visible?: boolean,
    onChange?: (data: any) => void,
    onClose?: () => void,
    config: any[],//配置表
    configName: string,//配置表名称
    columns: any[],//配置菜单
    version: string, // 版本号
}
function CustomListModel(props: customProps) {
    const { visible, onChange, onClose, config, configName, columns, version } = props
    // dataA 总数据
    // 数据开始
    const [dataA, setDataA] = useState<DataProps[]>(config)//备份原始数据
    const [data, setData] = useState<DataProps[]>(config)//变动的数据
    const [search, setSearch] = useState<string>('')  // 搜索字段
    const [selectData, setSelectData] = useState<dataProps[]>([])//选择的数据
    const [serverData, setServerData] = useState<dataProps[]>([])//备份的数据
    const [fixed, setFixed] = useState<{ left: string, right: string }>(localStorage.getItem(`myAdMonitorConfigFixed${version}_` + configName) ? JSON.parse(localStorage.getItem(`myAdMonitorConfigFixed${version}_` + configName) as any) : { left: '0', right: '0' })
    // 数据结束
    // 获取数据
    useEffect(() => {
        getUserList()
    }, [configName])
    // 获取个人配置
    const getUserList = () => {
            let mySelectData = localStorage.getItem(`myAdMonitorConfig${version}_` + configName)
            if (mySelectData) {//获取自定义配置
                let newMySelectData = JSON.parse(mySelectData)
                newMySelectData = newMySelectData.filter((item: any) => item && columns.some(c => c.dataIndex === item.dataIndex))//去除空项,并去除多余不存在的
                setSelectData(newMySelectData)
                setServerData(newMySelectData)
                localStorage.setItem(`myAdMonitorConfig${version}_` + configName, JSON.stringify(newMySelectData))//重新存下本地，避免更新后数据不对
            } else {//使用默认配置
                let newSelectData: any[] = []
                config?.forEach((item) => {
                    item?.data?.forEach((d: { default: any }) => {
                        if (d.default) {
                            newSelectData[d.default - 1] = d
                        }
                    })
                })
                setSelectData(newSelectData)
                setServerData(newSelectData)
            }
    }
    //首次赋值默认宽
    useEffect(() => {
        if (selectData?.length === columns?.length && !selectData?.every((item: any) => item.width)) {
            let newSelectData: any[] = []
            newSelectData = selectData?.map((item, index) => {
                item['width'] = columns[index]['width']
                return item
            })
            setSelectData(newSelectData)
            setServerData(newSelectData)
        }
    }, [selectData, columns])
    // 搜索 过滤
    const searchHandle = useCallback((value: string) => {
        setSearch(value)
        if (search) {
            let newData1: any[] = []
            dataA.forEach((item: DataProps) => {
                let newData = item.data.filter((listItem: dataProps) => {
                    if (listItem?.title?.includes(value)) {
                        return listItem
                    } else {
                        return null
                    }
                })
                if (newData?.length > 0) {
                    newData1.push({ ...item, data: newData })
                }
            })
            setData([...newData1])
        } else {
            setData(dataA)
        }
    }, [data, dataA, search])

    // 选中数据
    const selectHandle = useCallback((checked: boolean, data: dataProps) => {
        if (checked) {
            setSelectData([...selectData, { ...data }])
        } else {
            let newSelectData = selectData.filter((item: dataProps) => {
                if (item.dataIndex === data.dataIndex) {
                    return null
                } else {
                    return item
                }
            })
            setSelectData(newSelectData)
        }
    }, [selectData])

    // 每个大项 全选
    const checkAllHandle = useCallback((checked: boolean, value: string) => {
        let oldData = data.find((item: DataProps) => item.label === value)
        if (oldData) {
            if (checked) {
                let newSelectData: any[] = selectData
                oldData.data.forEach((item: dataProps) => {
                    if (!item.disabled && selectData.findIndex((selsectItem: dataProps) => selsectItem?.dataIndex === item?.dataIndex) === -1) {
                        newSelectData.push(item)
                    }
                })
                setSelectData([...newSelectData])
            } else {
                let newSelectData = selectData.filter((item: dataProps) => {
                    if (oldData?.data?.some((dataItem: dataProps) => dataItem.dataIndex === 'pos_type' ? false : dataItem?.dataIndex === item.dataIndex)) {
                        return null
                    } else {
                        return item
                    }
                })
                setSelectData(newSelectData)
            }
        }

    }, [selectData, data])

    const onSortEnd = ({ oldIndex, newIndex }: { oldIndex: number, newIndex: number }) => {
        setSelectData(arrayMove(selectData, oldIndex, newIndex))
    }
    // 提交
    const onSubmit = useCallback(() => {
        if (selectData.length > 0) {
            localStorage.setItem(`myAdMonitorConfig${version}_` + configName, JSON.stringify(selectData))
            localStorage.setItem(`myAdMonitorConfigFixed${version}_` + configName, JSON.stringify(fixed))
            message.success('保存成功')
            onChange && onChange({ selectData, fixed })
            onClose && onClose()
        } else {
            message.error('请选择最少一项！！！')
        }
    }, [serverData, selectData, fixed])
    // 恢复默认
    const defaultConfig = useCallback(() => {
        localStorage.removeItem(`myAdMonitorConfig${version}_` + configName)
        localStorage.removeItem(`myAdMonitorConfigFixed${version}_` + configName)
        if (configName.includes('起量')) {
            setFixed({ left: '0', right: '2' })
        }
        getUserList()
    }, [])
    // 设置悬浮
    const changeFixed = useCallback((name: string, value: string) => {
        let v = Number(value)
        if (!isNaN(v)) {
            setFixed({ ...fixed, [name]: value })
        }
    }, [fixed])
    //取消操作
    const cancel = () => {
        setSelectData(serverData)
        onClose && onClose()
    }
    // 设置配置参数
    const setConfig = useCallback((data) => {
        let newServerData = selectData?.map((item) => {
            if (item.dataIndex === data.dataIndex) {
                item = data
            }
            return item
        })
        setSelectData(newServerData)
    }, [selectData])
    return <Modal
        title={null}
        footer={null}
        visible={visible}
        width={1100}
        className='customListModel'
        onCancel={cancel}
    >
        <div className='content'>
            <div className='left'>
                <div className='leftSearch'>
                    <Input size="small" placeholder="输入关键词，搜索数据指标" onChange={(e) => { searchHandle(e.target.value) }} value={search} prefix={<SearchOutlined style={{ color: '#a3a3a3', fontSize: 18 }} />} allowClear bordered={false} />
                </div>

                <div className="dataList">
                    <Spin spinning={false}>
                        {data?.map((item: DataProps, index: number) => {
                            return <dl key={index}>
                                <dt>
                                    <Checkbox onChange={(e) => { checkAllHandle(e.target.checked, item.label) }} className='checkbox'>{item.label}</Checkbox>
                                </dt>
                                {item.data?.map((listItem: dataProps, listIndex: number) => {
                                    return <dd key={item.label + listIndex}>
                                        <Checkbox onChange={(e) => { selectHandle(e.target.checked, listItem) }} disabled={listItem.label === 'pos_type' || listItem?.disabled} checked={selectData.some((selectItem: { dataIndex: string }) => selectItem.dataIndex === listItem.dataIndex)} className='checkbox'>{listItem.title}</Checkbox>
                                    </dd>
                                })}
                            </dl>
                        })}
                    </Spin>
                </div>
            </div>
            <div className='right'>
                <div className='rightTitle'>
                    <div className="rightTitleLeft">已选<span>{selectData?.length}</span>项</div>
                    <a onClick={defaultConfig} style={{ marginRight: 30 }}>恢复默认</a>
                </div>
                <div style={{ display: 'flex', flexFlow: 'row nowarp', padding: '0 28px', justifyContent: 'space-between' }}>
                    <div>左侧固定列数：<InputNumber size='small' style={{ width: 50 }} onChange={(value: string) => { changeFixed('left', value) }} value={fixed.left} max={'100'} min={'0'} /></div>
                    <div>右侧固定列数：<InputNumber size='small' style={{ width: 50 }} onChange={(value: string) => { changeFixed('right', value) }} value={fixed.right} max={'100'} min={'0'} /></div>
                </div>
                <SortableList axis='y' onSortEnd={onSortEnd} useDragHandle>
                    {selectData.map((item: dataProps, index: number) => <SortableItem key={'li' + index} index={index} item={item} del={() => { selectHandle(false, item) }} setConfig={setConfig} />)}
                </SortableList>
                <div className='rightOperate'>
                    <div style={{ margin: '0 auto' }}>
                        <Button onClick={cancel}>取消</Button>
                        <Button type='primary' className='confirm' loading={false} onClick={() => { onSubmit() }} disabled={selectData?.length === 0}>确认</Button>
                    </div>
                </div>
            </div>
        </div>
    </Modal>
}

export default CustomListModel